@@ -1,4 +1,24 @@
 package Spreadsheet::HTML::File::Loader;
+use Carp;
+use strict;
+use warnings FATAL => 'all';
+
+sub parse {
+    my $file = shift;
+
+    if ($file =~ /\.csv$/) {
+        return Spreadsheet::HTML::File::CSV::parse( $file );
+    } elsif ($file =~ /\.html?$/) {
+        return Spreadsheet::HTML::File::HTML::parse( $file );
+    } elsif ($file =~ /\.jso?n$/) {
+        return Spreadsheet::HTML::File::JSON::parse( $file );
+    } elsif ($file =~ /\.ya?ml$/) {
+        return Spreadsheet::HTML::File::YAML::parse( $file );
+    } elsif ($file =~ /\.xls$/) {
+        return Spreadsheet::HTML::File::XLS::parse( $file );
+    }
+}
+
 =head1 NAME
 
 Spreadsheet::HTML::File::Loader - Load data from files.
@@ -29,26 +49,6 @@ Spreadsheet::HTML::File::Loader - Load data from files.
 
 =cut
 
-use Carp;
-use strict;
-use warnings FATAL => 'all';
-
-sub parse {
-    my $file = shift;
-
-    if ($file =~ /\.csv$/) {
-        return Spreadsheet::HTML::File::CSV::parse( $file );
-    } elsif ($file =~ /\.html?$/) {
-        return Spreadsheet::HTML::File::HTML::parse( $file );
-    } elsif ($file =~ /\.jso?n$/) {
-        return Spreadsheet::HTML::File::JSON::parse( $file );
-    } elsif ($file =~ /\.ya?ml$/) {
-        return Spreadsheet::HTML::File::YAML::parse( $file );
-    } elsif ($file =~ /\.xls$/) {
-        return Spreadsheet::HTML::File::XLS::parse( $file );
-    }
-}
-
 1;
 
 
@@ -85,6 +85,7 @@ our $NOT_AVAILABLE = $@;
 
 sub parse {
     my $file = shift;
+    return [[ "cannot load $file" ],[ 'No such file or directory' ]] unless -r $file;
     return [[ "cannot load $file" ],[ 'please install YAML' ]] if $NOT_AVAILABLE;
 
     my $data = YAML::LoadFile( $file );
@@ -127,9 +128,9 @@ our $NOT_AVAILABLE = $@;
 
 sub parse {
     my $file = shift;
+    open my $fh, '<', $file or return [[ "cannot load $file" ],[ $! ]];
     return [[ "cannot load $file" ],[ 'please install JSON' ]] if $NOT_AVAILABLE;
 
-    open my $fh, '<', $file or croak "Cannot read $file: $!\n";
     my $data = decode_json( do{ local $/; <$fh> } );
     close $fh;
     return $data;
@@ -181,7 +182,7 @@ sub parse {
     my @data;
     my $file = shift;
 
-    open my $fh, '<', $file or croak "Cannot read $file: $!\n";
+    open my $fh, '<', $file or return [[ "cannot load $file" ],[ $! ]];
 
     if ($PARSER) {
         my $csv = $PARSER->new;
@@ -237,6 +238,7 @@ our $NOT_AVAILABLE = $@;
 
 sub parse {
     my $file = shift;
+    return [[ "cannot load $file" ],[ 'No such file or directory' ]] unless -r $file;
     return [[ "cannot load $file" ],[ 'please install HTML::TableExtract' ]] if $NOT_AVAILABLE;
 
     my @data;
@@ -281,6 +283,7 @@ our $NOT_AVAILABLE = $@;
 
 sub parse {
     my $file = shift;
+    return [[ "cannot load $file" ],[ 'No such file or directory' ]] unless -r $file;
     return [[ "cannot load $file" ],[ 'please install Spreadsheet::ParseExcel' ]] if $NOT_AVAILABLE;
 
     my $parser   = Spreadsheet::ParseExcel->new;
